@@ -1,7 +1,7 @@
 /** @file clparam_list.cc
 \brief Methods for the command line parameter list class */
 /*
- * Copyright (C) 2000, 2006 - 2012
+ * Copyright (C) 2000, 2006 - 2016
  * Michael S. Borella <mike@borella.net> and
  * Michael Geng       <linux@MichaelGeng.de>
  *
@@ -148,16 +148,16 @@ void Clparam_list::logdump (Logfile& l) const
 {
   // preface
   l.write ("dumping parameter list...");
-  
+
   // do the global stuff here
   list<string>::const_iterator iter;
   for (iter = _include_list.begin (); iter != _include_list.end (); iter++)
     l.write ("  include file: " + *iter);
   for (iter = _mandatory_list.begin (); iter != _mandatory_list.end (); iter++)
     l.write ("  mandatory: " + *iter);
-  if (!get_global_callback ().empty ()); 
+  if (!get_global_callback ().empty ())
     l.write ("  global_callback: " + get_global_callback ());
- 
+
   // now do the parameters
   list<Clparam>::const_iterator iter2;
   for (iter2 = _params.begin (); iter2 != _params.end (); iter2++)
