@@ -1,21 +1,19 @@
+/* A Bison parser, made by GNU Bison 3.0.2.  */
 
-/* A Bison parser, made by GNU Bison 2.4.1.  */
+/* Bison interface for Yacc-like parsers in C
+
+   Copyright (C) 1984, 1989-1990, 2000-2013 Free Software Foundation, Inc.
 
-/* Skeleton interface for Bison's Yacc-like parsers in C
-   
-      Copyright (C) 1984, 1989, 1990, 2000, 2001, 2002, 2003, 2004, 2005, 2006
-   Free Software Foundation, Inc.
-   
    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.
-   
+
    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.
-   
+
    You should have received a copy of the GNU General Public License
    along with this program.  If not, see <http://www.gnu.org/licenses/>.  */
 
@@ -28,71 +26,79 @@
    special exception, which will cause the skeleton and the resulting
    Bison output files to be licensed under the GNU General Public
    License without this special exception.
-   
+
    This special exception was added by the Free Software Foundation in
    version 2.2 of Bison.  */
 
+#ifndef YY_YY_PARSER_H_INCLUDED
+# define YY_YY_PARSER_H_INCLUDED
+/* Debug traces.  */
+#ifndef YYDEBUG
+# define YYDEBUG 0
+#endif
+#if YYDEBUG
+extern int yydebug;
+#endif
 
-/* Tokens.  */
+/* Token type.  */
 #ifndef YYTOKENTYPE
 # define YYTOKENTYPE
-   /* Put the tokens into the symbol table, so that GDB and other debuggers
-      know about them.  */
-   enum yytokentype {
-     SLASH = 258,
-     RANGE_SPEC1 = 259,
-     RANGE_SPEC2 = 260,
-     FUNC_SPEC = 261,
-     NONE = 262,
-     OPEN_BRACE = 263,
-     CLOSE_BRACE = 264,
-     OPEN_SQUARE_BRACE = 265,
-     CLOSE_SQUARE_BRACE = 266,
-     EQUAL = 267,
-     INCLUDE = 268,
-     LT = 269,
-     GT = 270,
-     MANDATORY = 271,
-     EXIT_VALUE = 272,
-     BREAK_LINES = 273,
-     DOUBLEQUOTE = 274,
-     ASTERISK = 275,
-     EXCLAMATIONMARK = 276,
-     STORE_LONGINDEX = 277,
-     EXPORT_LONG_OPTIONS = 278,
-     GP_INCLUDE = 279,
-     ERR_MSG = 280,
-     COMMENT = 281,
-     DO_NOT_DOCUMENT = 282,
-     OPEN_ROUND_BRACE = 283,
-     CLOSE_ROUND_BRACE = 284,
-     COLON = 285,
-     ADD_FLAG = 286,
-     NO_STRUCT = 287,
-     CODE_END = 288,
-     QUOTED = 289,
-     FIRST_QUOTED = 290,
-     C_VAR = 291,
-     ALNUM = 292,
-     FILENAME = 293,
-     CHAR_VAL = 294,
-     FIRST_STR = 295,
-     USAGE_LINE = 296,
-     CODE_LINE = 297,
-     OPT_NAME = 298,
-     COMMENT_STR = 299,
-     FUNCTION = 300,
-     FLAG = 301,
-     INT = 302,
-     LONG = 303,
-     ULONG = 304,
-     INTMAX = 305,
-     UINTMAX = 306,
-     FLOAT = 307,
-     DOUBLE = 308,
-     CHAR = 309,
-     STRING = 310
-   };
+  enum yytokentype
+  {
+    SLASH = 258,
+    RANGE_SPEC1 = 259,
+    RANGE_SPEC2 = 260,
+    FUNC_SPEC = 261,
+    NONE = 262,
+    OPEN_BRACE = 263,
+    CLOSE_BRACE = 264,
+    OPEN_SQUARE_BRACE = 265,
+    CLOSE_SQUARE_BRACE = 266,
+    EQUAL = 267,
+    INCLUDE = 268,
+    LT = 269,
+    GT = 270,
+    MANDATORY = 271,
+    EXIT_VALUE = 272,
+    BREAK_LINES = 273,
+    DOUBLEQUOTE = 274,
+    ASTERISK = 275,
+    EXCLAMATIONMARK = 276,
+    STORE_LONGINDEX = 277,
+    EXPORT_LONG_OPTIONS = 278,
+    GP_INCLUDE = 279,
+    ERR_MSG = 280,
+    COMMENT = 281,
+    DO_NOT_DOCUMENT = 282,
+    OPEN_ROUND_BRACE = 283,
+    CLOSE_ROUND_BRACE = 284,
+    COLON = 285,
+    ADD_FLAG = 286,
+    NO_STRUCT = 287,
+    CODE_END = 288,
+    QUOTED = 289,
+    FIRST_QUOTED = 290,
+    C_VAR = 291,
+    ALNUM = 292,
+    FILENAME = 293,
+    CHAR_VAL = 294,
+    FIRST_STR = 295,
+    USAGE_LINE = 296,
+    CODE_LINE = 297,
+    OPT_NAME = 298,
+    COMMENT_STR = 299,
+    FUNCTION = 300,
+    FLAG = 301,
+    INT = 302,
+    LONG = 303,
+    ULONG = 304,
+    INTMAX = 305,
+    UINTMAX = 306,
+    FLOAT = 307,
+    DOUBLE = 308,
+    CHAR = 309,
+    STRING = 310
+  };
 #endif
 /* Tokens.  */
 #define SLASH 258
@@ -149,30 +155,26 @@
 #define CHAR 309
 #define STRING 310
 
-
-
-
+/* Value type.  */
 #if ! defined YYSTYPE && ! defined YYSTYPE_IS_DECLARED
-typedef union YYSTYPE
+typedef union YYSTYPE YYSTYPE;
+union YYSTYPE
 {
-
-/* Line 1676 of yacc.c  */
-#line 57 "parser.yy"
+#line 57 "parser.yy" /* yacc.c:1909  */
 
   char    *str;  /* string */
   int     i;
   param_type p;
 
-
-
-/* Line 1676 of yacc.c  */
-#line 170 "parser.h"
-} YYSTYPE;
+#line 170 "parser.h" /* yacc.c:1909  */
+};
 # define YYSTYPE_IS_TRIVIAL 1
-# define yystype YYSTYPE /* obsolescent; will be withdrawn */
 # define YYSTYPE_IS_DECLARED 1
 #endif
 
+
 extern YYSTYPE yylval;
 
+int yyparse (void);
 
+#endif /* !YY_YY_PARSER_H_INCLUDED  */
