@@ -2,7 +2,7 @@
  * Test program for testing the C output of genparse using a CUnit
  * (http://sourceforge.net/projects/cunit).
  *
- * Copyright (C) 2006 - 2012 Michael Geng <linux@MichaelGeng.de>
+ * Copyright (C) 2006 - 2016 Michael Geng <linux@MichaelGeng.de>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,7 +41,7 @@ static CU_TestInfo test_genparse[] = {
 };
 
 static CU_SuiteInfo suites[] = {
-  { "TestGenparse", NULL, NULL, test_genparse },
+  { "TestGenparse", NULL, NULL, NULL, NULL, test_genparse },
   CU_SUITE_INFO_NULL,
 };
 
